==> tmtccmd-7.0.0.tar.gz: tmtccmd-7.0.0/tmtccmd/util/countdown.py <==
from __future__ import annotations

import time
from typing import Optional
from deprecation import deprecated
from datetime import timedelta
from tmtccmd.version import get_version


def time_ms() -> int:
    return round(time.time() * 1000)


class Countdown:
    def __init__(self, init_timeout: Optional[timedelta]):
        if init_timeout is not None:
            self._timeout_ms = int(init_timeout / timedelta(milliseconds=1))
            self._start_time_ms = time_ms()
        else:
            self._timeout_ms = 0
            self._start_time_ms = 0

    @classmethod
    def from_seconds(cls, timeout_seconds: float) -> Countdown:
        return cls(timedelta(seconds=timeout_seconds))

    @classmethod
    def from_millis(cls, timeout_ms: int) -> Countdown:
        return cls(timedelta(milliseconds=timeout_ms))

    @property
    def timeout_ms(self) -> int:
        """Returns timeout as integer milliseconds."""
        return self._timeout_ms

    @property
    def timeout(self) -> timedelta:
        return timedelta(milliseconds=self._timeout_ms)

    @timeout.setter
    def timeout(self, timeout: timedelta):
        """Set a new timeout for the countdown instance."""
        self._timeout_ms = round(timeout / timedelta(milliseconds=1))

    def timed_out(self) -> bool:
        if round(time_ms() - self._start_time_ms) >= self._timeout_ms:
            return True
        else:
            return False

    def busy(self) -> bool:
        return not self.timed_out()

    def reset(self, new_timeout: Optional[timedelta] = None):
        if new_timeout is not None:
            self.timeout = new_timeout
        self.start()

    def start(self):
        self._start_time_ms = time_ms()

    def time_out(self):
        self._start_time_ms = 0

    @deprecated(
        deprecated_in="7.0.0",
        details="use remaining_time method instead",
        current_version=get_version(),
    )
    def rem_time(self):
        return self.remaining_time()

    def remaining_time(self) -> timedelta:
        """Remaining time left."""
        end_time = self._start_time_ms + self._timeout_ms
        current = time_ms()
        if end_time < current:
            return timedelta()
        return timedelta(milliseconds=end_time - current)

    def __repr__(self):
        return f"{self.__class__.__name__}(init_timeout={timedelta(milliseconds=self._timeout_ms)})"

    def __str__(self):
        return (
            f"{self.__class__.__class__} with"
            f" {timedelta(milliseconds=self._timeout_ms)} ms timeout,"
            f" {self.remaining_time()} time remaining"
        )

==> tmtccmd-8.0.0rc0.tar.gz: tmtccmd-8.0.0rc0/tmtccmd/util/countdown.py <==
from __future__ import annotations

import time
from typing import Optional
from deprecated.sphinx import deprecated
from datetime import timedelta


def time_ms() -> int:
    return round(time.time() * 1000)


class Countdown:
    def __init__(self, init_timeout: Optional[timedelta]):
        if init_timeout is not None:
            self._timeout_ms = int(init_timeout / timedelta(milliseconds=1))
            self._start_time_ms = time_ms()
        else:
            self._timeout_ms = 0
            self._start_time_ms = 0

    @classmethod
    def from_seconds(cls, timeout_seconds: float) -> Countdown:
        return cls(timedelta(seconds=timeout_seconds))

    @classmethod
    def from_millis(cls, timeout_ms: int) -> Countdown:
        return cls(timedelta(milliseconds=timeout_ms))

    @property
    def timeout_ms(self) -> int:
        """Returns timeout as integer milliseconds."""
        return self._timeout_ms

    @property
    def timeout(self) -> timedelta:
        return timedelta(milliseconds=self._timeout_ms)

    @timeout.setter
    def timeout(self, timeout: timedelta):
        """Set a new timeout for the countdown instance."""
        self._timeout_ms = round(timeout / timedelta(milliseconds=1))

    def timed_out(self) -> bool:
        if round(time_ms() - self._start_time_ms) >= self._timeout_ms:
            return True
        else:
            return False

    def busy(self) -> bool:
        return not self.timed_out()

    def reset(self, new_timeout: Optional[timedelta] = None):
        if new_timeout is not None:
            self.timeout = new_timeout
        self.start()

    def start(self):
        self._start_time_ms = time_ms()

    def time_out(self):
        self._start_time_ms = 0

    @deprecated(
        version="7.0.0",
        reason="use remaining_time method instead",
    )
    def rem_time(self):
        return self.remaining_time()

    def remaining_time(self) -> timedelta:
        """Remaining time left."""
        end_time = self._start_time_ms + self._timeout_ms
        current = time_ms()
        if end_time < current:
            return timedelta()
        return timedelta(milliseconds=end_time - current)

    def __repr__(self):
        return f"{self.__class__.__name__}(init_timeout={timedelta(milliseconds=self._timeout_ms)})"

    def __str__(self):
        return (
            f"{self.__class__.__class__} with"
            f" {timedelta(milliseconds=self._timeout_ms)} ms timeout,"
            f" {self.remaining_time()} time remaining"
        )
